# -*- coding: utf-8 -*-
"""
Tencent is pleased to support the open source community by making 蓝鲸智云PaaS平台社区版 (BlueKing PaaS Community
Edition) available.
Copyright (C) 2017-2021 THL A29 Limited, a Tencent company. All rights reserved.
Licensed under the MIT License (the "License"); you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://opensource.org/licenses/MIT
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.
"""

from __future__ import absolute_import

__all__ = ["celery_app", "RUN_VER", "APP_CODE", "SECRET_KEY", "BK_URL", "BASE_DIR"]

import os

# This will make sure the app is always imported when
# Django starts so that shared_task will use this app.
from blueapps.core.celery import celery_app

# app 基本信息


def get_env_or_raise(key):
    """Get an environment variable, if it does not exist, raise an exception"""
    value = os.environ.get(key)
    if not value:
        raise RuntimeError(
            (
                'Environment variable "{}" not found, you must set this variable to run this application.'
            ).format(key)
        )
    return value


# 应用 ID
APP_CODE = get_env_or_raise("BKPAAS_APP_ID")
# 应用用于调用云 API 的 Secret
SECRET_KEY = get_env_or_raise("BKPAAS_APP_SECRET")

# SaaS运行版本，如非必要请勿修改
RUN_VER = "ieod"
# 蓝鲸SaaS平台URL，例如 http://paas.bking.com
BK_URL = None

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['bk_plugin_runtime', 'bk_plugin_runtime.config']

package_data = \
{'': ['*'],
 'bk_plugin_runtime': ['static/*',
                       'static/account/*',
                       'static/admin/css/*',
                       'static/admin/fonts/*',
                       'static/admin/img/*',
                       'static/admin/img/gis/*',
                       'static/admin/js/*',
                       'static/admin/js/admin/*',
                       'static/admin/js/vendor/jquery/*',
                       'static/admin/js/vendor/xregexp/*',
                       'static/assets/*',
                       'static/assets/css/*',
                       'static/assets/fonts/*',
                       'static/assets/img/*',
                       'static/assets/js/*',
                       'static/djcelery/*',
                       'static/images/*',
                       'static/js/*',
                       'static/open/*',
                       'static/open/css/*',
                       'static/open/img/*',
                       'static/remote/*',
                       'static/remote/artDialog-6.0.4/*',
                       'static/remote/artDialog-6.0.4/css/*',
                       'static/remote/artDialog-6.0.4/new/css/*',
                       'static/remote/artDialog-6.0.4/new/js/*',
                       'static/remote/artdialog/*',
                       'static/remote/artdialog/skins/*',
                       'static/remote/artdialog/skins/icons/*',
                       'static/remote/jquery/*',
                       'static/remote/v3/assets/bootstrap-3.3.4/css/*',
                       'static/remote/v3/assets/bootstrap-3.3.4/fonts/*',
                       'static/remote/v3/assets/bootstrap-3.3.4/js/*',
                       'static/remote/v3/assets/jquery-ui-1.11.0.custom/*',
                       'static/remote/v3/assets/jquery-ui-1.11.0.custom/external/jquery/*',
                       'static/remote/v3/assets/jquery-ui-1.11.0.custom/images/*',
                       'static/remote/v3/assets/js/*',
                       'static/remote/v3/bk/css/*',
                       'static/remote/v3/bk/js/*',
                       'templates/*',
                       'templates/admin/*']}

install_requires = \
['Django>=2.2.6,<3.0.0',
 'blueapps==4.2.4',
 'celery>=4.4.0,<5.0.0',
 'ddtrace>=0.14.1,<0.15.0',
 'django-celery-beat>=2.0.0,<3.0.0',
 'django-celery-results>=1.2.1,<2.0.0',
 'django-cors-headers>=3.8.0,<4.0.0',
 'django-dbconn-retry>=0.1.5,<0.2.0',
 'djangorestframework>=3.12.4,<4.0.0',
 'drf-yasg>=1.20.0,<2.0.0',
 'gunicorn>=19.6.0,<20.0.0',
 'raven>=6.5.0,<7.0.0',
 'redis>=2.10.5,<3.0.0']

setup_kwargs = {
    'name': 'bk-plugin-runtime',
    'version': '1.2.2rc1',
    'description': 'bk plugin python django runtime',
    'long_description': None,
    'author': 'Your Name',
    'author_email': 'you@example.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
